@@ -22,7 +22,6 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-from __future__ import print_function
 from smartcard.CardConnection import CardConnection
 from smartcard.Exceptions import (CardConnectionException,
     NoCardException, SmartcardException)
@@ -33,7 +32,7 @@ from smartcard.scard import *
 def translateprotocolmask(protocol):
     """Translate CardConnection protocol mask into PCSC protocol mask."""
     pcscprotocol = 0
-    if None != protocol:
+    if protocol is not None:
         if CardConnection.T0_protocol & protocol:
             pcscprotocol |= SCARD_PROTOCOL_T0
         if CardConnection.T1_protocol & protocol:
@@ -48,7 +47,7 @@ def translateprotocolmask(protocol):
 def translateprotocolheader(protocol):
     """Translate protocol into PCSC protocol header."""
     pcscprotocol = 0
-    if None != protocol:
+    if protocol is not None:
         if CardConnection.T0_protocol == protocol:
             pcscprotocol = SCARD_PCI_T0
         if CardConnection.T1_protocol == protocol:
@@ -87,7 +86,7 @@ class PCSCCardConnection(CardConnection):
         # can disappear before __del__ is called
         self.disconnect()
         hresult = SCardReleaseContext(self.hcontext)
-        if hresult != 0:
+        if hresult != 0 and hresult != SCARD_E_INVALID_VALUE:
             raise CardConnectionException(
                 'Failed to release context: ' + \
                 SCardGetErrorMessage(hresult))
@@ -105,11 +104,11 @@ class PCSCCardConnection(CardConnection):
         if 0 == pcscprotocol:
             pcscprotocol = self.getProtocol()
 
-        if mode == None:
+        if mode is None:
             mode = SCARD_SHARE_SHARED
 
         # store the way to dispose the card
-        if disposition == None:
+        if disposition is None:
             disposition = SCARD_UNPOWER_CARD
         self.disposition = disposition
 
@@ -117,10 +116,8 @@ class PCSCCardConnection(CardConnection):
             self.hcontext, str(self.reader), mode, pcscprotocol)
         if hresult != 0:
             self.hcard = None
-            if SCARD_W_REMOVED_CARD == hresult:
-                raise NoCardException(
-                    'Unable to connect: ' + \
-                    SCardGetErrorMessage(hresult))
+            if hresult in (SCARD_W_REMOVED_CARD, SCARD_E_NO_SMARTCARD):
+                raise NoCardException('Unable to connect', hresult=hresult)
             else:
                 raise CardConnectionException(
                     'Unable to connect with protocol: ' + \
@@ -139,6 +136,54 @@ class PCSCCardConnection(CardConnection):
                     protocol = eval("CardConnection.%s_protocol" % dictProtocol[p])
         PCSCCardConnection.setProtocol(self, protocol)
 
+    def reconnect(self, protocol=None, mode=None, disposition=None):
+        """Reconnect to the card.
+
+        If protocol is not specified, connect with the default
+        connection protocol.
+
+        If mode is not specified, connect with SCARD_SHARE_SHARED.
+
+        If disposition is not specified, do a warm reset (SCARD_RESET_CARD)"""
+        CardConnection.reconnect(self, protocol)
+        if self.hcard is None:
+            raise CardConnectionException('Card not connected')
+
+        pcscprotocol = translateprotocolmask(protocol)
+        if 0 == pcscprotocol:
+            pcscprotocol = self.getProtocol()
+
+        if mode is None:
+            mode = SCARD_SHARE_SHARED
+
+        # store the way to dispose the card
+        if disposition is None:
+            disposition = SCARD_RESET_CARD
+        self.disposition = disposition
+
+        hresult, dwActiveProtocol = SCardReconnect(self.hcard, mode, pcscprotocol, self.disposition)
+        if hresult != 0:
+            self.hcard = None
+            if hresult in (SCARD_W_REMOVED_CARD, SCARD_E_NO_SMARTCARD):
+                raise NoCardException('Unable to reconnect', hresult=hresult)
+            else:
+                raise CardConnectionException(
+                    'Unable to reconnect with protocol: ' + \
+                    dictProtocol[pcscprotocol] + '. ' + \
+                    SCardGetErrorMessage(hresult))
+
+        protocol = 0
+        if dwActiveProtocol == SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1:
+            # special case for T0 | T1
+            # this happen when mode=SCARD_SHARE_DIRECT and no protocol is
+            # then negociated with the card
+            protocol = CardConnection.T0_protocol | CardConnection.T1_protocol
+        else:
+            for p in dictProtocol:
+                if p == dwActiveProtocol:
+                    protocol = eval("CardConnection.%s_protocol" % dictProtocol[p])
+        PCSCCardConnection.setProtocol(self, protocol)
+
     def disconnect(self):
         """Disconnect from the card."""
 
@@ -150,18 +195,18 @@ class PCSCCardConnection(CardConnection):
             CardConnection.disconnect(self)
         except TypeError:
             pass
-        if None != self.hcard:
+        if self.hcard is not None:
             hresult = SCardDisconnect(self.hcard, self.disposition)
+            self.hcard = None
             if hresult != 0:
                 raise CardConnectionException(
                     'Failed to disconnect: ' + \
                     SCardGetErrorMessage(hresult))
-            self.hcard = None
 
     def getATR(self):
         """Return card ATR"""
         CardConnection.getATR(self)
-        if None == self.hcard:
+        if self.hcard is None:
             raise CardConnectionException('Card not connected')
         hresult, reader, state, protocol, atr = SCardStatus(self.hcard)
         if hresult != 0:
@@ -173,18 +218,18 @@ class PCSCCardConnection(CardConnection):
     def doTransmit(self, bytes, protocol=None):
         """Transmit an apdu to the card and return response apdu.
 
-        bytes:      command apdu to transmit (list of bytes)
+        @param bytes:    command apdu to transmit (list of bytes)
 
-        protocol:   the transmission protocol, from CardConnection.T0_protocol,
-                    CardConnection.T1_protocol,
-                    or CardConnection.RAW_protocol
+        @param protocol: the transmission protocol, from
+            CardConnection.T0_protocol, CardConnection.T1_protocol, or
+            CardConnection.RAW_protocol
 
-        return:     a tuple (response, sw1, sw2) where
+        @return:     a tuple (response, sw1, sw2) where
                     sw1 is status word 1, e.g. 0x90
                     sw2 is status word 2, e.g. 0x1A
                     response are the response bytes excluding status words
         """
-        if None == protocol:
+        if protocol is None:
             protocol = self.getProtocol()
         CardConnection.doTransmit(self, bytes, protocol)
         pcscprotocolheader = translateprotocolheader(protocol)
@@ -194,7 +239,7 @@ class PCSCCardConnection(CardConnection):
                 'CardConnection.T0_protocol, ' + \
                 'CardConnection.T1_protocol, or ' + \
                 'CardConnection.RAW_protocol')
-        if None == self.hcard:
+        if self.hcard is None:
             raise CardConnectionException('Card not connected')
         hresult, response = SCardTransmit(
             self.hcard, pcscprotocolheader, bytes)
@@ -204,6 +249,10 @@ class PCSCCardConnection(CardConnection):
                 dictProtocolHeader[pcscprotocolheader] + '. ' + \
                 SCardGetErrorMessage(hresult))
 
+        if len(response) < 2:
+            raise CardConnectionException(
+                'Card returned no valid response')
+
         sw1 = (response[-2] + 256) % 256
         sw2 = (response[-1] + 256) % 256
 
@@ -254,4 +303,3 @@ if __name__ == '__main__':
     print("%r %x %x" % cc.transmit(SELECT + DF_TELECOM))
 
     print(cc.control(CM_IOCTL_GET_FEATURE_REQUEST, []))
-
