@@ -308,7 +308,11 @@ Builds a Python string from an ERRORSTRING
 
     if( NULL!=source )
     {
+#if (PY_MAJOR_VERSION >= 3) && defined(WIN32)
+        pystr = PyUnicode_Decode( (char*)source, strlen(source), "cp1250" , NULL);
+#else
         pystr = PyString_FromString( (char*)source );
+#endif
         *ptarget = pystr;
     }
     else
