@@ -22,7 +22,6 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-from __future__ import print_function
 from smartcard.sw.ErrorChecker import ErrorChecker
 import smartcard.sw.SWExceptions
 
@@ -71,27 +70,27 @@ class op21_ErrorChecker(ErrorChecker):
     """Open platform 2.1 error checker.
 
     This error checker raises the following exceptions:
-    - sw1 sw2
-    - 62  83                  WarningProcessingException
-    - 63  00                  WarningProcessingException
-    - 64  00                  ExecutionErrorException
-    - 65  81                  ExecutionErrorException
-    - 67  00                  CheckingErrorException
-    - 69  82 85               CheckingErrorException
-    - 6A  80 81 82 84 86 88   CheckingErrorException
-    - 6D  00                  CheckingErrorException
-    - 6E  00                  CheckingErrorException
-    - 94  84 85               CheckingErrorException
+      - sw1 sw2
+      - 62  83                  WarningProcessingException
+      - 63  00                  WarningProcessingException
+      - 64  00                  ExecutionErrorException
+      - 65  81                  ExecutionErrorException
+      - 67  00                  CheckingErrorException
+      - 69  82 85               CheckingErrorException
+      - 6A  80 81 82 84 86 88   CheckingErrorException
+      - 6D  00                  CheckingErrorException
+      - 6E  00                  CheckingErrorException
+      - 94  84 85               CheckingErrorException
 
     This checker does not raise exceptions on undefined sw1 values, e.g.:
-    - sw1 sw2
-    - 63  any
-    - 6F  any
+      - sw1 sw2
+      - 63  any
+      - 6F  any
 
     and on undefined sw2 values, e.g.:
-    - sw1 sw2
-    - 62  81 83
-    - 64  any except 00
+      - sw1 sw2
+      - 62  81 83
+      - 64  any except 00
 
 
     Use another checker in the error checking chain to raise exceptions
@@ -123,4 +122,4 @@ if __name__ == '__main__':
     try:
         ecs([], 0x94, 0x84)
     except smartcard.sw.SWExceptions.CheckingErrorException as e:
-        print(str(e) + "%x %x" % (e.sw1, e.sw2))
+        print(str(e) + "{:x} {:x}".format(e.sw1, e.sw2))
