@@ -65,7 +65,7 @@ class testcase_ATR(unittest.TestCase):
 
 def suite():
     suite1 = unittest.makeSuite(testcase_ATR)
-    return unittest.TestSuite((suite1))
+    return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
