@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 """Unit tests for smartcard.ATR
 
 This test case can be executed individually, or with all other test cases
@@ -117,7 +117,7 @@ class testcase_CAtr(unittest.TestCase):
 
 def suite():
     suite1 = unittest.makeSuite(testcase_CAtr)
-    return unittest.TestSuite((suite1))
+    return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
