@@ -90,7 +90,7 @@ class testcase_getATR(unittest.TestCase):
 
 def suite():
     suite1 = unittest.makeSuite(testcase_getATR)
-    return unittest.TestSuite((suite1))
+    return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
