@@ -211,7 +211,7 @@ if 'winscard' == resourceManager:
 
     def suite():
         suite1 = unittest.makeSuite(testcase_listcards)
-        return unittest.TestSuite((suite1))
+        return unittest.TestSuite(suite1)
 
 
 if __name__ == '__main__':
