@@ -42,9 +42,10 @@ class ReaderComboBox(wx.ComboBox, ReaderObserver):
         self.readermonitor = ReaderMonitor()
         self.readermonitor.addObserver(self)
 
-    def update(self, observable, (addedreaders, removedreaders)):
+    def update(self, observable, handlers):
         """Toolbar ReaderObserver callback that is notified when
         readers are added or removed."""
+        addedreaders, removedreaders = handlers
         for reader in addedreaders:
             item = self.Append(str(reader))
             self.SetClientData(item, reader)
@@ -77,12 +78,12 @@ class ReaderToolbar(wx.ToolBar):
             bmpReader = wx.Bitmap(ICO_READER, wx.BITMAP_TYPE_ICO)
         else:
             bmpReader = wx.ArtProvider_GetBitmap(
-                wx.ART_HELP_BOOK, wx.ART_OTHER, isz)
+                wx.ART_HELP_BOOK, wx.ART_OTHER, tsize)
         if None != ICO_SMARTCARD:
             bmpCard = wx.Bitmap(ICO_SMARTCARD, wx.BITMAP_TYPE_ICO)
         else:
             bmpCard = wx.ArtProvider_GetBitmap(
-                wx.ART_HELP_BOOK, wx.ART_OTHER, isz)
+                wx.ART_HELP_BOOK, wx.ART_OTHER, tsize)
         self.readercombobox = ReaderComboBox(self)
 
         # create and add controls
