@@ -7,7 +7,7 @@
 import unittest
 from smartcard.scard import SCardGetErrorMessage
 from smartcard.scard import SCARD_S_SUCCESS, SCARD_F_INTERNAL_ERROR
-from distutils.util import get_platform
+import platform
 
 
 class TestError(unittest.TestCase):
@@ -17,7 +17,7 @@ class TestError(unittest.TestCase):
 
         # do not test on Windows
         # the error messages are different and localized
-        if get_platform() in ('win32', 'win-amd64'):
+        if platform.system() == 'Windows':
             return
 
         expected = "Command successful."
